# -*- coding: utf-8 -*-

from opbeat.utils.compat import TestCase

import opbeat
# from opbeat.utils import get_versions


# class GetVersionsTest(TestCase):
#     def test_exact_match(self):
#         versions = get_versions(['opbeat'])
#         self.assertEquals(versions.get('opbeat'), opbeat.VERSION)

#     def test_parent_match(self):
#         versions = get_versions(['opbeat.contrib.django'])
#         self.assertEquals(versions.get('opbeat'), opbeat.VERSION)
